 # -*- coding: utf-8 -*-
"""
Copyright © 2014 Ford Hurley <ford.hurley@gmail.com>
This work is free. You can redistribute it and/or modify it under the
terms of the Do What The Fuck You Want To Public License, Version 2,
as published by Sam Hocevar. See the COPYING file for more details.
"""

__version__ = '0.0.1'

from s3url.s3 import parse_keys, parse_obj, connect, get_s3_url
import s3url.time



 # -*- coding: utf-8 -*-
from setuptools import setup

from s3url import __version__

setup(
    name='s3url',
    version=__version__,
    author='Ford Hurley',
    author_email='ford.hurley@gmail.com',
    url='https://github.com/fordhurley/s3url',
    description='A simple command line utility for generating time-sensitive, '
                'sharable urls for private s3 files',
    license='WTFPL v2',

    scripts=['scripts/s3url'],
    packages=['s3url'],
    install_requires=[
        'boto>=2.17',
        'docopt>=0.6.1'
    ],
    tests_require=['nose>=1.0']
)
